==> apache-asterixdb-0.9.4-source-release.zip: apache-asterixdb-0.9.4/asterix-common/src/main/java/org/apache/asterix/common/transactions/ITxnIdFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.common.transactions;

import org.apache.hyracks.algebricks.common.exceptions.AlgebricksException;

public interface ITxnIdFactory {
    /**
     * Creates a new unique transaction id.  The implementation must ensure this id is unique within the cluster
     *
     * @return the new transaction id
     */
    TxnId create() throws AlgebricksException;

    long getIdBlock(int blockSize);

    /**
     * Ensure that future transaction ids are larger than the supplied id
     *
     * @param id
     *            the value to ensure future created transaction ids are larger than
     */
    void ensureMinimumId(long id) throws AlgebricksException;

    /**
     * The highest transaction id this factory has created
     *
     * @return the max transaction id
     */
    long getMaxTxnId();
}

==> apache-asterixdb-0.9.8-source-release.zip: apache-asterixdb-0.9.8/asterix-common/src/main/java/org/apache/asterix/common/transactions/ITxnIdFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.common.transactions;

import org.apache.hyracks.algebricks.common.exceptions.AlgebricksException;

public interface ITxnIdFactory {
    /**
     * Creates a new unique transaction id.  The implementation must ensure this id is unique within the cluster
     *
     * @return the new transaction id
     */
    TxnId create() throws AlgebricksException;

    long getIdBlock(int blockSize);

    /**
     * Ensure that future transaction ids are larger than the supplied id
     *
     * @param id
     *            the value to ensure future created transaction ids are larger than
     */
    void ensureMinimumId(long id);

    /**
     * The highest transaction id this factory has created
     *
     * @return the max transaction id
     */
    long getMaxTxnId();
}
